# Python SDK Documentation

Documentation for the Python SDK has been moved to the unified documentation at:

**[/docs/guides/](/docs/guides/)**

## Quick Links

- [AutoEval Guide](/docs/guides/autoeval.md)
- [Local Execution](/docs/guides/local-execution.md)
- [OpenTelemetry Integration](/docs/guides/opentelemetry-integration.md)
- [Structured Output Validation](/docs/guides/structured-output-validation.md)
- [Eval Delegate Scanner](/docs/guides/eval-delegate-scanner.md)

## Why the Move?

We've consolidated all documentation into a unified structure that supports multiple languages (Python, TypeScript, Go, Java) with consistent formatting and language availability indicators.
